@@ -83,7 +83,7 @@ fi
 
 # set defaults, if nothing given
 [[ -z "${KERNEL}" ]] && KERNEL="$(uname -r)"
-[[ -z "${RELEASENAME}" ]] && RELEASENAME="2k14-R5"
+[[ -z "${RELEASENAME}" ]] && RELEASENAME="2k15-R1"
 [[ -z "${IMAGENAME}" ]] && IMAGENAME="Archlinux-allinone-$(date +%Y.%m)"
 
 IMAGENAME_OLD="${IMAGENAME}"
@@ -230,7 +230,7 @@ title           Arch Linux x86_64 Archboot EFISTUB
 linux           /boot/vmlinuz_x86_64
 initrd          /boot/intel-ucode.img
 initrd          /boot/initramfs_x86_64.img
-options         cgroup_disable=memory add_efi_memmap _X64_UEFI=1
+options         cgroup_disable=memory add_efi_memmap _X64_UEFI=1 rootfstype=ramfs
 architecture    x64
 GUMEOF
 	
@@ -239,7 +239,7 @@ GUMEOF
 # linux           /boot/vmlinuz_i686
 # initrd          /boot/intel-ucode.img
 # initrd          /boot/initramfs_i686.img
-# options         cgroup_disable=memory add_efi_memmap _IA32_UEFI=1
+# options         cgroup_disable=memory add_efi_memmap _IA32_UEFI=1 rootfstype=ramfs
 # architecture    ia32
 # GUMEOF
 	
@@ -316,7 +316,7 @@ set timeout="2"
 menuentry "Arch Linux x86_64 Archboot Non-EFISTUB" {
     set gfxpayload=keep
     search --no-floppy --set=root --file /boot/vmlinuz_x86_64
-    linux /boot/vmlinuz_x86_64 cgroup_disable=memory add_efi_memmap _X64_UEFI=1
+    linux /boot/vmlinuz_x86_64 cgroup_disable=memory add_efi_memmap _X64_UEFI=1 rootfstype=ramfs
     initrd /boot/intel-ucode.img /boot/initramfs_x86_64.img
 }
 
@@ -369,14 +369,14 @@ set timeout="2"
 menuentry "Arch Linux x86_64 Archboot - EFI MIXED MODE" {
     set gfxpayload=keep
     search --no-floppy --set=root --file /boot/vmlinuz_x86_64
-    linux /boot/vmlinuz_x86_64 cgroup_disable=memory add_efi_memmap _IA32_UEFI=1
+    linux /boot/vmlinuz_x86_64 cgroup_disable=memory add_efi_memmap _IA32_UEFI=1 rootfstype=ramfs
     initrd /boot/intel-ucode.img /boot/initramfs_x86_64.img
 }
 
 menuentry "Arch Linux i686 Archboot Non-EFISTUB" {
     set gfxpayload=keep
     search --no-floppy --set=root --file /boot/vmlinuz_i686
-    linux /boot/vmlinuz_i686 cgroup_disable=memory add_efi_memmap _IA32_UEFI=1
+    linux /boot/vmlinuz_i686 cgroup_disable=memory add_efi_memmap _IA32_UEFI=1 rootfstype=ramfs
     initrd /boot/intel-ucode.img /boot/initramfs_i686.img
 }
 
@@ -424,13 +424,13 @@ MENU RESOLUTION 1280 800
 LABEL archboot-x86_64
     MENU LABEL Arch Linux x86_64 Archboot - EFI MIXED MODE
     LINUX /boot/vmlinuz_x86_64
-    APPEND cgroup_disable=memory add_efi_memmap _IA32_UEFI=1
+    APPEND cgroup_disable=memory add_efi_memmap _IA32_UEFI=1 rootfstype=ramfs
     INITRD /boot/intel-ucode.img,/boot/initramfs_x86_64.img
 
 LABEL archboot-i686
     MENU LABEL Arch Linux i686 Archboot - EFI HANDOVER PROTOCOL
     LINUX /boot/vmlinuz_i686
-    APPEND cgroup_disable=memory add_efi_memmap _IA32_UEFI=1
+    APPEND cgroup_disable=memory add_efi_memmap _IA32_UEFI=1 rootfstype=ramfs
     INITRD /boot/intel-ucode.img,/boot/initramfs_i686.img
 EOF
 	
